@@ -21,6 +21,7 @@
 #ifndef __MBUFFER_H__
 #define __MBUFFER_H__
 
+#include "ctr.h"
 #include "kstrax_ioc.h"
 
 /*
@@ -33,9 +34,11 @@ int kstrax_reset_index(void);
 int kstrax_read_basetime(int *);
 int kstrax_copy_status(trace_stat_t *);
 int kstrax_pid_spec(pid_t);
-int kstrax_syscall_spec_wrapper(int);
-void pre_sys_call_record(const struct pt_regs);
-void post_sys_call_record(const struct pt_regs);
+int kstrax_syscall_spec(int);
+int kstrax_set_current_index(void);
 ssize_t kstrax_read(struct file *, char __user *, size_t, loff_t *);
 
+void pre_sys_call_record(const ctr_handler_t);
+void post_sys_call_record(const ctr_handler_t);
+
 #endif /* __MBUFFER_H__ */
